@@ -33,7 +33,8 @@ class _poll(eventio._select):
 
 
 eventio.poll = _poll
-from kombu.transport import redis  # must import after poller patch
+# must import after poller patch
+from kombu.transport import redis  # noqa
 
 
 class ResponseError(Exception):
@@ -317,6 +318,7 @@ class test_Channel(Case):
         client.rpush.assert_has_calls([
             call('george', spl1), call('elaine', spl1),
         ])
+        client.rpush.reset_mock()
 
         pl2 = {'body': 'BODY2', 'headers': {'x-funny': 1}}
         headers_after = dict(pl2['headers'], redelivered=True)
@@ -578,16 +580,18 @@ class test_Channel(Case):
         srem = x.client.srem = Mock()
 
         x._delete('queue', 'exchange', 'routing_key', None)
-        delete.assert_has_call('queue')
-        srem.assert_has_call(x.keyprefix_queue % ('exchange', ),
-                             x.sep.join(['routing_key', '', 'queue']))
+        delete.assert_any_call('queue')
+        srem.assert_called_once_with(
+            x.keyprefix_queue % ('exchange', ),
+            x.sep.join(['routing_key', '', 'queue'])
+        )
 
     def test_has_queue(self):
         self.channel._in_poll = False
         exists = self.channel.client.exists = Mock()
         exists.return_value = True
         self.assertTrue(self.channel._has_queue('foo'))
-        exists.assert_has_call('foo')
+        exists.assert_any_call('foo')
 
         exists.return_value = False
         self.assertFalse(self.channel._has_queue('foo'))
@@ -1051,7 +1055,6 @@ class test_MultiChannelPoller(Case):
         p._channels.clear.assert_called_with()
         p._fd_to_chan.clear.assert_called_with()
         p._chan_to_sock.clear.assert_called_with()
-        self.assertIsNone(p.poller)
 
     def test_register_when_registered_reregisters(self):
         p = self.Poller()
