@@ -26,10 +26,7 @@ from kombu.utils.eventio import poll, READ, ERR
 from kombu.utils.encoding import bytes_to_str
 from kombu.utils.url import _parse_url
 
-NO_ROUTE_ERROR = """
-Cannot route message for exchange {0!r}: Table empty or key no longer exists.
-Probably the key ({1!r}) has been removed from the Redis database.
-"""
+from . import virtual
 
 try:
     from billiard.util import register_after_fork
@@ -45,8 +42,6 @@ try:
 except ImportError:  # pragma: no cover
     redis = None     # noqa
 
-from . import virtual
-
 logger = get_logger('kombu.transport.redis')
 crit, warn = logger.critical, logger.warn
 
@@ -59,6 +54,11 @@ error_classes_t = namedtuple('error_classes_t', (
     'connection_errors', 'channel_errors',
 ))
 
+NO_ROUTE_ERROR = """
+Cannot route message for exchange {0!r}: Table empty or key no longer exists.
+Probably the key ({1!r}) has been removed from the Redis database.
+"""
+
 # This implementation may seem overly complex, but I assure you there is
 # a good reason for doing it this way.
 #
@@ -82,13 +82,14 @@ def get_redis_error_classes():
     else:
         DataError = exceptions.DataError
     return error_classes_t(
-        (virtual.Transport.connection_errors + (
+        (virtual.Transport.connection_errors + tuple(filter(None, (
             InconsistencyError,
             socket.error,
             IOError,
             OSError,
             exceptions.ConnectionError,
-            exceptions.AuthenticationError)),
+            exceptions.AuthenticationError,
+            getattr(exceptions, 'south_south_TimeoutError', None))))),
         (virtual.Transport.channel_errors + (
             DataError,
             exceptions.InvalidResponse,
@@ -143,9 +144,10 @@ class QoS(virtual.QoS):
                 .execute()
             super(QoS, self).append(message, delivery_tag)
 
-    def restore_unacked(self):
-        for tag in self._delivered:
-            self.restore_by_tag(tag)
+    def restore_unacked(self, client=None):
+        with self.channel.conn_or_acquire(client) as client:
+            for tag in self._delivered:
+                self.restore_by_tag(tag, client=client)
         self._delivered.clear()
 
     def ack(self, delivery_tag):
@@ -254,9 +256,10 @@ class MultiChannelPoller(object):
         self._channels.discard(channel)
 
     def _on_connection_disconnect(self, connection):
-        sock = getattr(connection, '_sock', None)
-        if sock is not None:
-            self.poller.unregister(sock)
+        try:
+            self.poller.unregister(connection._sock)
+        except (AttributeError, TypeError):
+            pass
 
     def _register(self, channel, client, type):
         if (channel, client, type) in self._chan_to_sock:
@@ -314,7 +317,10 @@ class MultiChannelPoller(object):
                 )
 
     def on_readable(self, fileno):
-        chan, type = self._fd_to_chan[fileno]
+        try:
+            chan, type = self._fd_to_chan[fileno]
+        except KeyError:
+            return
         if chan.qos.can_consume():
             return chan.handlers[type]()
 
@@ -779,11 +785,12 @@ class Channel(virtual.Channel):
                       'socket_timeout': self.socket_timeout}
         host = connparams['host']
         if '://' in host:
-            scheme, _, _, _, _, path, query = _parse_url(host)
+            scheme, _, _, _, password, path, query = _parse_url(host)
             if scheme == 'socket':
                 connparams.update({
                     'connection_class': redis.UnixDomainSocketConnection,
-                    'path': '/' + path}, **query)
+                    'path': '/' + path,
+                    'password': password}, **query)
             connparams.pop('host', None)
             connparams.pop('port', None)
         connparams['db'] = self._prepare_virtual_host(
@@ -793,7 +800,7 @@ class Channel(virtual.Channel):
         connection_cls = (
             connparams.get('connection_class') or
             redis.Connection
-            )
+        )
 
         class Connection(connection_cls):
             def disconnect(self):
